@@ -1,7 +1,7 @@
 __author__ = 'Altertech, http://www.altertech.com/'
 __copyright__ = 'Copyright (C) 2018-2020 Altertech Group'
 __license__ = 'Apache License 2.0'
-__version__ = '2.0.17'
+__version__ = '2.0.21'
 
 import platform
 import os
@@ -283,6 +283,10 @@ def get_db():
             return g.conn
 
 
+def get_db_engine():
+    return _d.db
+
+
 def get_timeout():
     timeout = config.get('timeout')
     return timeout if timeout else default_timeout
